local f = CreateFrame("Frame")
f:RegisterEvent("ADDON_LOADED")

f:SetScript("OnEvent", function(self, event, arg)
  if event == "ADDON_LOADED" and arg == "EnchantExport" then
    SLASH_EXPORTENCHANTS1 = "/exportenchants"
    SlashCmdList["EXPORTENCHANTS"] = function()
      EnchantExport_RunExport()
    end

    -- Begin checking for CraftFrame
    EnchantExport_WaitForCraftFrame()
  end
end)

function EnchantExport_WaitForCraftFrame()
  local wait = CreateFrame("Frame")
  wait:SetScript("OnUpdate", function(self)
    if CraftFrame and CraftFrame:IsShown() then
      self:SetScript("OnUpdate", nil)
      EnchantExport_AttachButton()
    end
  end)
end

function EnchantExport_RunExport()
  local prof = GetCraftName()
  if not prof or prof ~= "Enchanting" then
    print("❌ Please open your Enchanting profession first.")
    return
  end

  local enchants = {}
  for i = 1, GetNumCrafts() do
    local name, _, typ = GetCraftInfo(i)
    if typ ~= "header" then
      local link = GetCraftItemLink(i)
      if link then
        local spellID = link:match("enchant:(%d+)")
        if spellID then
          table.insert(enchants, spellID)
        end
      end
    end
  end

  if #enchants == 0 then
    print("❌ No enchants found.")
    return
  end

local name, realm = UnitFullName("player")
local full = realm and (name .. "-" .. realm) or name
local result = full .. "|" .. date("!%Y-%m-%dT%H:%M:%S") .. "|" .. table.concat(enchants, ",")
  EnchantExport_ShowBox(result)
end

function EnchantExport_ShowBox(text)
  if EnchantExportFrame then EnchantExportFrame:Hide() end

  local frame = CreateFrame("Frame", "EnchantExportFrame", UIParent, "BackdropTemplate")
  frame:SetSize(640, 160)
  frame:SetPoint("CENTER")
  frame:SetBackdrop({
    bgFile = "Interface/Tooltips/UI-Tooltip-Background",
    edgeFile = "Interface/Tooltips/UI-Tooltip-Border",
    tile = true, tileSize = 16, edgeSize = 16,
    insets = { left = 4, right = 4, top = 4, bottom = 4 }
  })
  frame:SetBackdropColor(0, 0, 0, 0.85)
  frame:SetMovable(true)
  frame:EnableMouse(true)
  frame:RegisterForDrag("LeftButton")
  frame:SetScript("OnDragStart", frame.StartMoving)
  frame:SetScript("OnDragStop", frame.StopMovingOrSizing)

  local scroll = CreateFrame("ScrollFrame", nil, frame, "UIPanelScrollFrameTemplate")
  scroll:SetPoint("TOPLEFT", 10, -10)
  scroll:SetPoint("BOTTOMRIGHT", -30, 10)

  local editBox = CreateFrame("EditBox", nil, scroll)
  editBox:SetMultiLine(true)
  editBox:SetFontObject(ChatFontNormal)
  editBox:SetWidth(580)
  editBox:SetAutoFocus(true)
  editBox:SetText(text)
  editBox:HighlightText()
  editBox:SetScript("OnEscapePressed", function() frame:Hide() end)

  scroll:SetScrollChild(editBox)

  frame:Show()
end

function EnchantExport_AttachButton()
  if CraftFrame.EnchantExportButton then return end
  if GetCraftName() ~= "Enchanting" then return end

  local btn = CreateFrame("Button", "EnchantExportButton", CraftFrame, "UIPanelButtonTemplate")
  btn:SetText("Export")
  btn:SetWidth(80)
  btn:SetHeight(22)
  btn:SetPoint("TOPLEFT", CraftFrame, "TOPLEFT", 15, -68)

  btn:SetScript("OnClick", function()
    EnchantExport_RunExport()
  end)

  btn:Show()
  CraftFrame.EnchantExportButton = btn

  local versionLabel = CraftFrame:CreateFontString(nil, "OVERLAY", "GameFontNormalSmall")
  versionLabel:SetPoint("LEFT", btn, "RIGHT", 8, 0)
  versionLabel:SetText("EnchantExport (Beta 1.4)")
  versionLabel:SetTextColor(1, 1, 1)
end
